function value = CQTEHDD(qtlBounds,p1,p1deriv,tau,c,epsilon,kappa,h1)
% This function calculates the second term of Gamma_1.
%
% Inputs:
%       input1 - qtlBounds (4 * l matrix)
%       input2 - propensity score
%       input3 - derivative of propensity score
%       input4 - tau (l * 1 vector)
%       input5 - c
%       input6 - (tuning parameter) epsilon
%       input7 - (tuning parameter) kappa
%       input8 - h1
%
% Outputs:
%       the second term of Gamma_1 (4 * l matrix)
%
%       1. lower bound, x = 1
%       2. upper bound, x = 0
%       3. upper bound, x = 1
%       4. lower bound, x = 0
%
% Subfunctions: T2, T4
%
% Written by: Linqi Zhang
% October 2022

value = nan(4,length(tau));

for j = 1:4
    if mod(j,2) == 0
        x = 0;
    else 
        x = 1;
    end
    
    if (j == 2) || (j==3)
        Tvalue = T2(p1,p1deriv,x,tau,c,epsilon,kappa,h1); % 1 * l matrix
    else 
        Tvalue = T4(p1,p1deriv,x,tau,c,epsilon,kappa,h1);
    end
    
    value(j,:) = qtlBounds(j,:) .* Tvalue;
end

end