function [lGamma3x1,uGamma3x0,uGamma3x1,lGamma3x0] = ...
    Gamma3(W,tuningParams,pmax,p1,x,y,WsuppSize,pW,interaction)
% This function calculates Gamma3
% Gamma3 = 1/N \sum_i \int (1,x,W_i)'gamma(S2) d\tau
%
% Inputs:
%       input1 - W
%       input2 - tuning parameters
%       input3 - the max of (p1, 1-p1) for each observation
%       input4 - propensity score
%       input5 - interpolation nodes for the quantile ceofficients, x
%       input6 - interpolation nodes for the quantile ceofficients, y
%       input7 - size of the support of W. For continuous W, this is the
%       number of observations.
%       input8 - probability mass of W. Used only for discrete W.
%       input9 - whether to include X*W in the quantile regression. The
%       default is to include W only. In that case, specify only the first
%       eight input arguments.
% Outputs:
%       Gamma3
%
% Subfunction: quantileBounds
%
% Written by: Linqi Zhang
% October 2022

[cgrid,~,cNum,tau] = setGrid(tuningParams,pmax);

lCate = nan(cNum, WsuppSize);
uCate = nan(cNum, WsuppSize);
lGamma2x0 = nan(cNum, WsuppSize);
uGamma2x0 = nan(cNum, WsuppSize);
lGamma2x1 = nan(cNum, WsuppSize);
uGamma2x1 = nan(cNum, WsuppSize);

if nargin == 8
    noDeriv = 1;
elseif nargin == 9
    noDeriv = 2;
end
    
for n = 1:WsuppSize
    suppW = W(n,:);
    cAll = [pmax(n,1);cgrid];  
    
    for i = 1:cNum
        
        c = cAll(i);
        
        if c<=pmax(n,1)

            qtlBounds = quantileBounds(suppW, [], p1(n), ...
                tau,c,tuningParams.epsilon,x,y,noDeriv);     

            lCate(i,n) = mean(qtlBounds(1,:) - qtlBounds(2,:));
            uCate(i,n) = mean(qtlBounds(3,:) - qtlBounds(4,:));
            lGamma2x1(i,n) = mean(qtlBounds(1,:));
            uGamma2x0(i,n) = mean(qtlBounds(2,:));
            uGamma2x1(i,n) = mean(qtlBounds(3,:));
            lGamma2x0(i,n) = mean(qtlBounds(4,:));

            
        else
            lCate(i,n) = lCate(1,n);
            uCate(i,n) = uCate(1,n);
            lGamma2x1(i,n) = lGamma2x1(1,n);
            uGamma2x0(i,n) = uGamma2x0(1,n);
            uGamma2x1(i,n) = uGamma2x1(1,n);
            lGamma2x0(i,n) = lGamma2x0(1,n);
        end
    end
end

if ~isempty(pW)
    lGamma3x1 = lGamma2x1*pW;
    uGamma3x0 = uGamma2x0*pW;
    uGamma3x1 = uGamma2x1*pW;
    lGamma3x0 = lGamma2x0*pW;
else
    lGamma3x1 = mean(lGamma2x1,2);
    uGamma3x0 = mean(uGamma2x0,2);
    uGamma3x1 = mean(uGamma2x1,2);
    lGamma3x0 = mean(lGamma2x0,2);
end