function [lGamma3x1term1,uGamma3x0term1,uGamma3x1term1,lGamma3x0term1, ...
    uGamma3x0,lGamma3x0,lAte,uAte] ...
    = Gamma3derivTerm1(Data,DataBootstrap,tuningParams,pmax,p1origin, ...
    x,y,WsuppSize,pW,xBoot,yBoot)
% This function calculates the first term of the derivative of Gamma3
%
% First term = 1/N \sum_i \int (1,x,W_i)'h2(S(x,W_i,tau,beta)) d\tau
%
% Inputs:
%       input1 - data
%       input2 - bootstrap data
%       input3 - tuning parameters
%       input4 - the max of (p1, 1-p1) for each observation
%       input5 - propensity score of the original data
%       input6 - interpolation nodes for the quantile ceofficients, x
%       input7 - interpolation nodes for the quantile ceofficients, y
%       input8 - size of the support of W. For continuous W, this is the
%       number of observations.
%       input9 - probability mass of W. Used only for discrete W.
%       input10 - (bootstrap data) interpolation nodes for the quantile 
%       ceofficients, x
%       input11 - (bootstrap data) interpolation nodes for the quantile 
%       ceofficients, x
%
% Outputs:
%       first term of the derivative of Gamma3
%
% Subfunctions: setGrid, quantileCoefNodes, Gamma3
%
% Written by: Linqi Zhang
% October 2022

[~,cAll,cNum,tau] = setGrid(tuningParams,pmax);
nObs = size(Data.X,1); 
nCov = size(Data.W,2)+1;
 
% Calculate 1/N \sum_i \int (1,x,W_i)'gamma_b^*(S2) d\tau
if nargin == 9
    
    nBoot = size(DataBootstrap.X,3);
    lGamma3x0boot = nan(cNum,nBoot);
    uGamma3x0boot = nan(cNum,nBoot);
    lGamma3x1boot = nan(cNum,nBoot);
    uGamma3x1boot = nan(cNum,nBoot);
    
    parfor b = 1:nBoot
        % For each bootstrap dataset, calculate interpolation nodes
        bDataBootstrap = [];
        bDataBootstrap.X = DataBootstrap.X(:,:,b);
        bDataBootstrap.W = DataBootstrap.W(:,:,b);
        bDataBootstrap.Y = DataBootstrap.Y(:,:,b);
        [xb,yb] = quantileCoefNodes(bDataBootstrap,tuningParams,nCov,2);

        % For each of the bootstrap dataset and each observation W_i, 
        % calculate the quantile bounds and CATE.

        [lGamma3x1boot(:,b),uGamma3x0boot(:,b), ...
            uGamma3x1boot(:,b),lGamma3x0boot(:,b)] = ...
            Gamma3(Data.W,tuningParams,pmax,p1origin,xb,yb,WsuppSize,pW);

    end
    
elseif nargin == 11
    
    nBoot = size(xBoot,3);
    lGamma3x0boot = nan(cNum,nBoot);
    uGamma3x0boot = nan(cNum,nBoot);
    lGamma3x1boot = nan(cNum,nBoot);
    uGamma3x1boot = nan(cNum,nBoot);    
    
    parfor b = 1:nBoot
        xb = xBoot(:,:,b);
        yb = yBoot(:,:,b);
        % For each of the bootstrap dataset and each observation W_i, 
        % calculate the quantile bounds and CATE.

        [lGamma3x1boot(:,b),uGamma3x0boot(:,b), ...
            uGamma3x1boot(:,b),lGamma3x0boot(:,b)] = ...
            Gamma3(Data.W,tuningParams,pmax,p1origin,xb,yb,WsuppSize,pW);

    end    
end

% Calculate 1/N \sum_i \int (1,x,W_i)'gamma(S2) d\tau 
% (Bounds on ATE, original data)

tATE = tic;
[lGamma3x1,uGamma3x0,uGamma3x1,lGamma3x0] = ...
    Gamma3(Data.W,tuningParams,pmax,p1origin,x,y,WsuppSize,pW);
disp('Time needed to compute the ATE bounds:')
toc(tATE)

lAte = lGamma3x1-uGamma3x0;
uAte = uGamma3x1-lGamma3x0;

lGamma3x1term1 = sqrt(nObs) * (lGamma3x1boot - lGamma3x1); 
uGamma3x0term1 = sqrt(nObs) * (uGamma3x0boot - uGamma3x0);
uGamma3x1term1 = sqrt(nObs) * (uGamma3x1boot - uGamma3x1); 
lGamma3x0term1 = sqrt(nObs) * (lGamma3x0boot - lGamma3x0); 