% This function calculates T1

% px denotes L(x,w'beta)
% pxDeriv denotes L_beta(x,w'beta)'
% beta is the logit coefficient estimated from original data
% beta_b is the logit coefficient estimated from bootstrapped data
% h1 is sqrt(N)*(beta_b - beta)

function value = T1(p1,p1deriv,x,tau,c,epsilon,kappa,h1)

px = x*(p1) + (1-x)*(1-p1);
pxDeriv = x*(p1deriv) + (1-x)*(-p1deriv);

tol = 10e-8;
temp1 = tau + (c./px) .* min(tau,1-tau);

index1 = (tol + temp1 < min(tau./px,(1-epsilon)) - kappa );
index2 = (tol + tau ./ px < min(temp1,1-epsilon) - kappa);
index3 = (tol + 1-epsilon < min(temp1,tau./px) - kappa);
index4 = (abs(temp1 - tau./px) <= kappa + tol).* ...
    (tol + max(temp1,tau./px) < 1-epsilon-kappa);
index5 = (abs(temp1 - (1-epsilon)) <= kappa + tol).* ...
    (tol + max(temp1,1-epsilon) < tau./px - kappa);
index6 = (abs(tau./px - (1-epsilon)) <= kappa + tol).* ...
    (tol + max(tau./px,1-epsilon) < temp1 - kappa);
index7 = ((abs(temp1 - (1-epsilon)) <= kappa + tol) + ...
    (abs(tau./px - (1-epsilon)) <= kappa + tol) + ...
    (abs(temp1 - tau./px) <= kappa + tol) >= 2);

term1 = -c .* min(tau,1-tau) .* (pxDeriv*h1) ./ (px).^2;
term2 = -tau .* (pxDeriv*h1) ./ (px).^2;

T1 = term1;
T2 = term2;
T3 = 0;
T4 = min(term1,term2);
T5 = min(term1,0);
T6 = min(term2,0);
T7 = min([term1; term2; zeros(1,length(tau))]);

value = index1 .* T1 + index2 .* T2 + index3 .* T3 + index4 .* T4 ...
    + index5 .* T5 + index6 .* T6 + index7 .* T7;

end