% This function calculates T3

% px denotes L(x,w'beta)
% pxDeriv denotes L_beta(x,w'beta)'
% beta is the logit coefficient estimated from original data
% beta_b is the logit coefficient estimated from bootstrapped data
% h1 is sqrt(N)*(beta_b - beta)

function value = T3(p1,p1deriv,x,tau,c,epsilon,kappa,h1)

px = x*(p1) + (1-x)*(1-p1);
pxDeriv = x*(p1deriv) + (1-x)*(-p1deriv);

tol = 10e-8;
temp1 = tau - c./px .* min(tau,1-tau);
temp2 = (tau-1) ./ px + 1;

index1 = (temp1 - (max(temp2,epsilon) + kappa) > tol);
index2 = (temp2 - (max(temp1,epsilon) + kappa)> tol);
index3 = (epsilon - (max(temp1,temp2) + kappa)> tol);
index4 = (abs(temp1 - temp2) <= kappa + tol) .* ...
    (min(temp1,temp2) - (epsilon + kappa)> tol);
index5 = (abs(temp1 - epsilon) <= kappa + tol) .* ...
    (min(temp1,epsilon) - (temp2 + kappa)> tol);
index6 = (abs(temp2  - epsilon) <= kappa + tol) .* ...
    (min(temp2,epsilon) - (temp1 + kappa) > tol);
index7 = ((abs(temp1 - temp2) <= kappa + tol) + ...
    (abs(temp1 - epsilon) <= kappa + tol) + ...
    (abs(temp2 - epsilon) <= kappa + tol) >=2 );

term1 = c .* min(tau,1-tau) .* (pxDeriv*h1) ./ (px).^2;
term2 = (1-tau) .* (pxDeriv*h1) ./ (px).^2;

T1 = term1;
T2 = term2;
T3 = 0;
T4 = max(term1,term2);
T5 = max(term1,0);
T6 = max(term2,0);
T7 = max([term1; term2; zeros(1,length(tau))]);

value = index1 .* T1 + index2 .* T2 + index3 .* T3 + index4 .* T4 ...
    + index5 .* T5 + index6 .* T6 + index7 .* T7;
end