function computeAte(Data,tuningParams,iSim,dgpChoice,tuningChoice,d)
%
% Inputs:
%       input1 - data
%       input2 - tuning parameters
%       input3 - simulation sample index
%       input4 - dgp choice index
%       input5 - tuning parameter choice index
%       input6 - polynomial order
% 
% Outputs:
%       true value of ATE bounds
%
% Subfunctions: propensityScore, quantileCoefNodes, Gamma3
%
% Written by: Linqi Zhang
% October 2022

nObs = size(Data.X,1);
Worigin = Data.W;

%% 1.Calculate propensity score(s)

if d == 1
    Data.W = Worigin;
elseif d == 2
    Data.W = [Worigin Worigin.^2];
elseif d == 3
    Data.W = [Worigin Worigin.^2 Worigin.^3];
elseif d == 0
    Data.W = Worigin;
end

[p1origin,~,beta] = propensityScore(Data);
pmax = max([p1origin,(1-p1origin)],[],2);

%% 2.Approximate quantile coefficients

if d == 1
    Data.W = [Worigin Worigin.*Data.X];
elseif d == 2
    Data.W = [Worigin Worigin.^2 Worigin.*Data.X Worigin.^2.*Data.X];
elseif d == 3
    Data.W = [Worigin Worigin.^2 Worigin.^3 Worigin.*Data.X Worigin.^2.*Data.X Worigin.^3.*Data.X];
elseif d == 0 
    Data.W = Worigin;
end

nCov = size(Data.W,2);
nCov = nCov + 1;
[x,y] = quantileCoefNodes(Data,tuningParams,nCov,2);

%% 3.Estimate bound functions

pW = [];
WsuppSize = nObs;

if d == 1
    Data.W = Worigin;
elseif d == 2
    Data.W = [Worigin Worigin.^2];
elseif d == 3
    Data.W = [Worigin Worigin.^2 Worigin.^3];
elseif d == 0
    Data.W = Worigin;
end

[lGamma3x1,uGamma3x0,uGamma3x1,lGamma3x0] = ...
    Gamma3(Data.W,tuningParams,pmax,p1origin,x,y,WsuppSize,pW,1);

lAte = lGamma3x1-uGamma3x0;
uAte = uGamma3x1-lGamma3x0;

saveSuffix = 'dgp%d_tuning%d_n%d_poly%d_sim%d.mat';
savePath = 'output/fullMC/misspecification';

saveFileName = ...
    sprintf(strcat(savePath,'/ate/ate_',saveSuffix),...
    dgpChoice,tuningChoice,nObs,d,iSim);
save(saveFileName,'lAte','uAte');