function Data = generateMCdata(params,dgpChoice,iSim,action)
% This code generates simulation data
%
% Inputs:
%       input1 - dgp parameters
%       input2 - dgp choice index
%       input3 - simulation sample index
%       input4 - action can be either "read" or "save".
% Outputs:
%       data
%
% Subfunctions: trueQuantileFunction_MC
%
% Written by: Linqi Zhang
% October 2022

nObs = params.nObs;

if nargin > 2 && action == "read"
    
    loadFileName = ...
        sprintf('output/fullMC/MCsample/dgp%d_n%d_sim%d.mat',...
        dgpChoice,nObs,iSim);
    load(loadFileName,'Data');
    
elseif nargin == 2 || (nargin > 2 && action == "save")

    if ismember(dgpChoice, [1 5 6 7 8])

        beta0 = params.betaTrue(1,1);
        beta1 = params.betaTrue(2,1);

        Data.W = double(rand(nObs,1)<=0.5);
        Data.X = double(rand(nObs,1)<=(1./(1+exp(-beta0-beta1.*Data.W))));
        U = rand(nObs,1);
        Data.Y = trueQuantileFunction_MC(params,U,Data.X,Data.W);

    elseif ismember(dgpChoice, [10 11 12])

        Data.W = randn(nObs,1);

        rescaleW = 2*pi*normcdf(Data.W)-pi;
        sinW = sin([rescaleW 2*rescaleW 3*rescaleW]);
        cosW = cos([rescaleW 2*rescaleW 3*rescaleW]);
        kW = params.lambda0 + sinW*params.lambdaS + cosW*params.lambdaC;

        Data.X = double(rand(nObs,1)<=(1./(1+exp(-kW))));
        U = rand(nObs,1);
        Data.Y = trueQuantileFunction_MC(params,U,Data.X,Data.W);
        
    elseif ismember(dgpChoice, [13 14 15])
        
        Data.W = normrnd(-1/2,3/4,[nObs,1]);
        kW = params.lambda0 + params.lambda1*Data.W + ...
            params.lambda2*Data.W.^2 + params.lambda3*Data.W.^3;
        
        Data.X = double(rand(nObs,1)<=(1./(1+exp(-kW))));
        U = rand(nObs,1);
        Data.Y = trueQuantileFunction_MC(params,U,Data.X,Data.W);

    end
    
    if nargin > 2
        saveFileName = ...
            sprintf('output/fullMC/MCsample/dgp%d_n%d_sim%d.mat',...
            dgpChoice,nObs,iSim);
        save(saveFileName,'Data');  
    end
    
end


clear nSim nObs beta0 beta1 a b normalDist trancateNormalDist s
end