function [trueLate,trueUate] = getAteTrue(dgpChoice,tuningChoice,RIntgrid)
% This function computes the true value of ATE bounds.
%
% Inputs:
%       input1 - dgp choice index
%       input2 - tuning parameter index
%       input3 - number of nodes used for numerical integration (over the
%       population distribution of W)
%       
% Outputs:
%       true value of ATE bounds
%
% Subfunctions: setDgpParams, setTuningParams, trueGamma1
%
% Written by: Linqi Zhang
% October 2022

params = setDgpParams(dgpChoice);
tuningParams = setTuningParams(tuningChoice);

if nargin == 3
    tuningParams.RIntgrid = RIntgrid;
end

cgrid = linspace(0,1,tuningParams.Ncgrid);
tau = linspace(0,1,tuningParams.NIntgrid);
%% Compute identified set bound functions for Gamma3

uGamma3 = nan(length(cgrid),2); %XsuppSize
lGamma3 = nan(length(cgrid),2);

for i = 1:length(cgrid)

    c = cgrid(i);
    [uGamma1,lGamma1] = trueGamma1(params,tau,c,tuningParams);
    
    uGamma2 = mean(uGamma1,1);
    lGamma2 = mean(lGamma1,1);

    if ismember(dgpChoice, [1 5 6 7 8])
        
        uGamma3(i,:) = uGamma2(:,:,1)*params.q + ...
            uGamma2(:,:,2)*(1-params.q);
        lGamma3(i,:) = lGamma2(:,:,1)*params.q + ...
            lGamma2(:,:,2)*(1-params.q);
    
    elseif ismember(dgpChoice, [10 11 12 13 14 15])
        
        uGamma3(i,:) = mean(uGamma2,3);
        lGamma3(i,:) = mean(lGamma2,3);
        
    end

end
trueLate = lGamma3(:,2) - uGamma3(:,1);
trueUate = uGamma3(:,2) - lGamma3(:,1);

if nargin == 3
    saveFileName = ...
        sprintf('output/dgp/trueAte_dgp%d_tuning%d_nW%d.mat',dgpChoice,tuningChoice,tuningParams.RIntgrid); 
    save(saveFileName,'trueLate','trueUate');
elseif nargin == 2
    saveFileName = ...
        sprintf('output/dgp/trueAte_dgp%d_tuning%d.mat',dgpChoice,tuningChoice); 
    save(saveFileName,'trueLate','trueUate');    
end
