% This is the main program that computes and plots the confidence sets for
% the bounds on ATE and ATT for the LaLonde 1986 empirical appplication.

clear;

% c = parcluster;
% %-- Set the wall time to 100 hours, (Max is 120 hours, 5 days)
% c.AdditionalProperties.WallTime='100:00:00'; 
% c.AdditionalProperties.MemUsage='3G'; %-- Set memory use to 3GB per core
% c.AdditionalProperties.ProcsPerNode=10; %----10 cores per node
% saveProfile(c)
% parpool(60) %---Open a pool of 60 workers (Max 512)
% 

% User customizable
tuningChoiceVec = [23];
alphaVec = [0.05;0.01];

%%
% Don't modify the code below
dgpChoice = 0; % 0: empirical
nTuning = length(tuningChoiceVec);

for iTuning=1:nTuning
    tuningChoice = tuningChoiceVec(iTuning);
    
    for iSample=1:2 % 1: sample1; 2: sample3; 3: test

    Data = importData(iSample);
    sampleSize = size(Data.X,1);
    tuningParams = setTuningParams(tuningChoice,sampleSize);

    rng(81349+dgpChoice+iSample,'twister')   

    DataBootstrap = generateBoot(tuningParams,sampleSize,Data);

    tCI = tic;
    computeCI(Data,DataBootstrap,tuningParams,alphaVec,iSample,dgpChoice,tuningChoice);
    disp('Time needed to compute the CIs:')
    toc(tCI)
    
    end
end

plotEmpirical(tuningChoiceVec,dgpChoice,alphaVec,'ATE');
plotEmpirical(tuningChoiceVec,dgpChoice,alphaVec,'ATT');
