% This is the main program that assess the impact of the choice of tuning 
% parameters eta and kappa. It computes the coverage probability for each
% fixed c.

clear;

% c = parcluster;
% %-- Set the wall time to 100 hours, (Max is 120 hours, 5 days)
% c.AdditionalProperties.WallTime='100:00:00'; 
% c.AdditionalProperties.MemUsage='3G'; %-- Set memory use to 3GB per core
% c.AdditionalProperties.ProcsPerNode=10; %----10 cores per node
% saveProfile(c)
% parpool(60) %---Open a pool of 60 workers (Max 512)

run setChoiceMC.m

for iSampleSize=1:nSampleSize
    sampleSize = sampleSizeVec(iSampleSize);
    
for iDgp=1:nDgp
    dgpChoice = dgpChoiceVec(iDgp);
    params = setDgpParams(dgpChoice);
    params.nObs = sampleSize;
    rng(81349+dgpChoice+sampleSize,'twister');
    seedForSimulation = randi(1e+7,1,nSimulations);
    
    for iSim=1:nSimulations
        rng(seedForSimulation(1,iSim),'twister');
        Data = generateMCdata(params,dgpChoice,iSim,'save');
    end
    
    getAteTrue(dgpChoice,1); % true ATE for epsilon = 0.05; if epsilon takes other values, change the second argument
    
    for iTuning=1:nTuning
        tuningChoice = tuningChoiceVec(iTuning);
        tuningParams = setTuningParams(tuningChoice,sampleSize);

        parfor iSim=1:nSimulations
            rng(seedForSimulation(1,iSim),'twister');
            Data = generateMCdata(params,dgpChoice,iSim,'read');
            DataBootstrap = generateBoot(tuningParams,sampleSize,Data);
            computeCI(Data,DataBootstrap,tuningParams,alphaVec,iSim,dgpChoice,tuningChoice);
            
        end
        
        % Load population distribution
        load(sprintf('output/dgp/trueAte_dgp%d_tuning%d.mat',dgpChoice,1)); % true ATE for epsilon = 0.05; if epsilon takes other values, need to modify the second argument
        cnum = length(trueLate);
        
        % Load MC results
        MC.CILower = nan(cnum,nAlpha,nSimulations);
        MC.CIUpper = nan(cnum,nAlpha,nSimulations);  
        
        for iSim=1:nSimulations            
            load(sprintf('output/fullMC/CI/CI_dgp%d_tuning%d_n%d_sim%d.mat',...
            dgpChoice,tuningChoice,sampleSize,iSim))
            MC.CILower(:,:,iSim) = CI(2:41,1:nAlpha);
            MC.CIUpper(:,:,iSim) = CI(2:41,1+nAlpha:end);
            
        end

        for iAlpha=1:nAlpha % alpha1 is 0.1; alpha2 is 0.05.
            coverageProb = nan(cnum,1);

            for i=1:cnum
                coverageProb(i) = sum(MC.CIUpper(i,iAlpha,:)>=trueUate(i) & ...
                    MC.CILower(i,iAlpha,:)<=trueLate(i))/nSimulations;
            end
            
            saveFileName = ...
                sprintf('output/fullMC/CP/CP_dgp%d_tuning%d_n%d_sim%d_alpha%d.mat',...
                dgpChoice,tuningChoice,sampleSize,nSimulations,iAlpha);
            save(saveFileName,'coverageProb');
            
            coverageProb = table(coverageProb);
            saveFileName = ...
                sprintf('tables/CP_dgp%d_tuning%d_n%d_sim%d_alpha%d.xls',...
                dgpChoice,tuningChoice,sampleSize,nSimulations,iAlpha);
            writetable(coverageProb, saveFileName, 'Sheet', 1);
            
            trueAte = [trueLate,trueUate];
            printDirectory = (sprintf('images/CI_dgp%d_tuning%d_n%d_sim%d_alpha%d',...
                dgpChoice,tuningChoice,sampleSize,nSimulations,iAlpha));
            plotCI(trueAte,squeeze(MC.CILower(:,iAlpha,:)),...
                squeeze(MC.CIUpper(:,iAlpha,:)),printDirectory) % need to change the scale of y axis in the plotCI function
        end

    end
end
end

run computeLargestDeviation.m
run plotCoverageProb.m