% This is the main program that assess the impact of misspecification of
% the functional for of the propensity score and conditional quantile
% function.

clear;

% c = parcluster;
% c.AdditionalProperties.WallTime='60:00:00'; 
% c.AdditionalProperties.MemUsage='3G'; %-- Set memory use to 3GB per core
% c.AdditionalProperties.ProcsPerNode=10; %----10 cores per node
% saveProfile(c)
% parpool(80) %---Open a pool of 80 workers (Max 512)

%%
dgpChoiceVec = [14];
tuningChoiceVec = [1];
nSimulations = 500;
sampleSizeVec = [500;2000];
optimalR = 250000;
sampleStatus = 'save';
resultType = 'original';

nDgpChoice = length(dgpChoiceVec);
nTuningChoice = length(tuningChoiceVec);
nSampleSize = length(sampleSizeVec);

%% Chunk 1

run generateRandomDraw.m

for iTuningChoice = 1:nTuningChoice
    tuningChoice = tuningChoiceVec(iTuningChoice);
    tuningParams = setTuningParams(tuningChoice);
for iDgpChoice = 1:nDgpChoice 
    dgpChoice = dgpChoiceVec(iDgpChoice);
    params = setDgpParams(dgpChoice);

    getAteTrue(dgpChoice,tuningChoice,optimalR);
    
    for iSampleSize = 1:nSampleSize

        sampleSize = sampleSizeVec(iSampleSize);
        params.nObs = sampleSize;
        rng(81349+dgpChoice+sampleSize,'twister');
        seedForSimulation = randi(1e+7,1,nSimulations);

        parfor iSim=1:nSimulations
            
            switch sampleStatus
                case 'read'
                    arg = {iSim 'read'};
                case 'save'
                    arg = {iSim 'save'};
                case 'generate'
                    arg = {};
            end
            rng(seedForSimulation(1,iSim),'twister'); 
            Data = generateMCdata(params,dgpChoice,arg{:});    
            computeAte(Data,tuningParams,iSim,dgpChoice,tuningChoice,1);
            computeAte(Data,tuningParams,iSim,dgpChoice,tuningChoice,2);
            computeAte(Data,tuningParams,iSim,dgpChoice,tuningChoice,3);
        end
    end
end
end

%% Chunk 2

switch resultType
    case 'original'
        savePrefix = '';
        savePath = 'ate/';
    case 'recentered'
        savePrefix = 'recenter_';
        savePath = 'ate_recenter/';
end

for iTuningChoice = 1:nTuningChoice
    tuningChoice = tuningChoiceVec(iTuningChoice);
for iDgpChoice = 1:nDgpChoice 
    dgpChoice = dgpChoiceVec(iDgpChoice);
    
    
    load(sprintf('output/dgp/trueAte_dgp%d_tuning%d_nW%d.mat',dgpChoice,tuningChoice,optimalR));
    trueAte = [trueLate trueUate];

    for iSampleSize = 1:nSampleSize
        sampleSize = sampleSizeVec(iSampleSize);
        for d = 1:3
            fileList = dir(sprintf(strcat('output/fullMC/misspecification/',savePath,'ate_dgp%d_tuning%d_n%d_poly%d_sim*.mat'),...
                    dgpChoice,tuningChoice,sampleSize,d));
            hatAte = cell(1, numel(fileList));
            for iFile = 1:numel(fileList)
                file = load(strcat(fileList(iFile).folder,'/',fileList(iFile).name));
                hatAte{iFile} = [file.lAte file.uAte];
            end
            hatAteM = [hatAte{:}];

            lAteStat(:,:,d) = computeStats(trueAte, hatAteM, 0);
            uAteStat(:,:,d) = computeStats(trueAte, hatAteM, 1);
        end

        saveFileName = ...
            sprintf(strcat('output/fullMC/misspecification/',savePrefix,'stat_dgp%d_tuning%d_n%d.mat'),...
            dgpChoice,tuningChoice,sampleSize);
        save(saveFileName,'lAteStat','uAteStat');

        lAteImse(iSampleSize,:) = squeeze(mean(lAteStat(:,4,:),1))';
        uAteImse(iSampleSize,:) = squeeze(mean(uAteStat(:,4,:),1))';

    end

    ateImse = round([uAteImse;lAteImse],3);
    run makeTableIMSE.m


    for iSampleSize = 1:nSampleSize
        sampleSize = sampleSizeVec(iSampleSize);
        for d = 1:3
            for iSim=1:nSimulations            
                load(sprintf(strcat('output/fullMC/misspecification/',savePath,'ate_dgp%d_tuning%d_n%d_poly%d_sim%d.mat'),...
                dgpChoice,tuningChoice,sampleSize,d,iSim))
                MC.CILower(:,iSim) = lAte(2:41);
                MC.CIUpper(:,iSim) = uAte(2:41);

            end
            printDirectory = (sprintf(strcat('images/',savePrefix,'misspec_dgp%d_tuning%d_n%d_poly%d_sim%d'),...
                dgpChoice,tuningChoice,sampleSize,d,nSimulations));
            plotCI(trueAte,squeeze(MC.CILower(:,:)),...
                squeeze(MC.CIUpper(:,:)),printDirectory)
        end
    end
end
end