function plotCI(trueATE,CILowerVec,CIUpperVec,printDirectory)
% This function plots the empirical distribution of the estimated bound 
% functions.
%
% Inputs:
%       input1 - true ATE bounds
%       input2 - estimated lower bound
%       input3 - estimated upper bound
%       input4 - save path
% Outputs:
%       empirical distribution of the estimated bound functions.
%
% Written by: Linqi Zhang
% October 2022

if nargin == 4
    h = figure('visible','off');
else
    h = figure('visible','on');    
end

cnum = size(trueATE,1);
cgrid = linspace(0,1,cnum)';
    
hold on;

for i=1:size(CILowerVec,2)
    CILower = CILowerVec(:,i);
    plot(cgrid,CILower,'-k','LineWidth',0.1)
end

for i=1:size(CIUpperVec,2)
    CIUpper = CIUpperVec(:,i);
    plot(cgrid,CIUpper,'-k','LineWidth',0.1)
end    

plot(cgrid,trueATE(:,1),'-','LineWidth',2,'Color',[0 1 1]);
plot(cgrid,trueATE(:,2),'-','LineWidth',2,'Color',[0 1 1]);


hold off;

xlabel('c')
ylim([-2,14]); % the appropriate y axis is different for the two simulation exercises
yticks(-2:2:14);

ax = gca;
outerpos = ax.OuterPosition;
ti = ax.TightInset; 
left = outerpos(1) + ti(1);
bottom = outerpos(2) + ti(2);
ax_width = outerpos(3) - ti(1) - ti(3);
ax_height = outerpos(4) - ti(2) - ti(4);
ax.Position = [left bottom ax_width ax_height];

if nargin == 4
    print(h,'-depsc',printDirectory);
end  



end