function plotCP(coverageProbMat,alpha,printDirectory)
% This function plots the pointwise coverage probabilities of the estimated 
% confidence sets as a function of c.
%
% Inputs:
%       input1 - coverage probabilities at each c
%       input2 - nominal coverage probability
%       input3 - save path
%
% Outputs:
%       pointwise coverage probabilities
%
% Written by: Linqi Zhang
% October 2022

if nargin == 3
    h = figure('visible','off');
else
    h = figure('visible','on');    
end

cnum = size(coverageProbMat,1);
cgrid = linspace(0,1,cnum)';
nominal = 1-alpha;

hold on;

p1 = plot(cgrid,coverageProbMat(:,1),'-k','LineWidth',1);
yline(nominal,':k','LineWidth',1)

hold off;

ylim([0.8,1]);
yticks([0.8 nominal 1])
yticklabels({'0.8',num2str(nominal),'1'})
xlabel('c')
set(findall(gcf,'-property','FontSize'),'FontSize',12)

if nargin == 3
    print(h,'-deps',printDirectory);
end  

end