function plotEmpirical(tuningChoiceVec,dgpChoice,alphaVec,boundType,nObs)
% This function plots the confidence sets for the empirical application.
%
% dgpChoice = 0 represents the LaLonde1986 application
% When dgpChoice = 0, the input argument nObs is not necessary.

if dgpChoice == 0
    nSamples = 2;
else
    nSamples = 1;
end

if isequal(boundType,'ATE')
    loadPath = 'output/empirical/ate/ate_dgp%d_tuning%d_n%d_sample%d.mat';
    loadPathCI = 'output/empirical/CI/CI_dgp%d_tuning%d_n%d_sample%d.mat';
    printPath = 'images/empirical/CI_ATE_dgp%d_tuning%d';
    tablePath = 'output/empirical/cBreakDown_ATE.xls';
elseif isequal(boundType,'ATT')
    loadPath = 'output/empirical/att/att_dgp%d_tuning%d_n%d_sample%d.mat';
    loadPathCI = 'output/empirical/CI/CIatt_dgp%d_tuning%d_n%d_sample%d.mat';
    printPath = 'images/empirical/CI_ATT_dgp%d_tuning%d';
    tablePath = 'output/empirical/cBreakDown_ATT.xls';  
end

nTuning = length(tuningChoiceVec);
nAlpha = length(alphaVec);

cBreakDownCI = nan(nTuning,nSamples,nAlpha);
cBreakDown = nan(nTuning,nSamples);

for iTuning=1:nTuning
    tuningChoice = tuningChoiceVec(iTuning);
    h = figure('visible','off');
    hold on;
    for iSample=1:nSamples

        if dgpChoice==0 && iSample==1
            nObs = 445;
        elseif dgpChoice==0 && iSample==2
            nObs = 390;
        end

        load(sprintf(loadPath,...
        dgpChoice,tuningChoice,nObs,iSample));
        
        if isequal(boundType,'ATE')
            lBound = lAte(2:end,:);
            uBound = uAte(2:end,:);
        elseif isequal(boundType,'ATT')
            lBound = lAtt(2:end,:);
            uBound = uAtt(2:end,:);
        end
        
        cNum = size(lBound,1);
        cgrid = linspace(0,1,cNum)';
        
        if iSample==1
            plot(cgrid,lBound,'--k','LineWidth',1)
            plot(cgrid,uBound,'--k','LineWidth',1)
        elseif iSample==2
            plot(cgrid,lBound,'-k','LineWidth',1)
            plot(cgrid,uBound,'-k','LineWidth',1)    
        end
        
        
        [~,ind] = unique(lBound);
        cBreakDown(iTuning,iSample) = ...
            interp1(lBound(ind,1),cgrid(ind),0);
        
        load(sprintf(loadPathCI,...
            dgpChoice,tuningChoice,nObs,iSample));
        CInew = nan(cNum,2);
        CI = CI(2:end,:);
        
        for iAlpha=2:2
            
            % Monotonize CI from right
            for i=1:cNum
                c = cgrid(i);
                CInew(i,1) = max(CI(i:end,iAlpha));
                CInew(i,2) = min(CI(i:end,iAlpha+nAlpha));              
            end
            
            [~,ind] = unique(CInew(:,1));
            cBreakDownCI(iTuning,iSample,iAlpha) = ...
                interp1(CInew(ind,1),cgrid(ind),0);
            
            if iSample==1
                plot(cgrid,CInew(:,1),'-.k','LineWidth',0.5)
                plot(cgrid,CInew(:,2),'-.k','LineWidth',0.5)
            elseif iSample==2
                plot(cgrid,CInew(:,1),':k','LineWidth',1)
                plot(cgrid,CInew(:,2),':k','LineWidth',1)
            end    
        end

    end    
    ax = gca;
    ax.YAxis.Exponent = 0;  
    
    if isequal(boundType,'ATE')
        set(gca, 'Xtick', 0:0.2:1, 'Ytick', -15000:5000:25000);
        ylim([-15000,25000]);
    elseif isequal(boundType,'ATT')
        set(gca, 'Xtick', 0:0.2:1, 'Ytick', -20000:5000:15000);
        ylim([-20000,15000]);
    end
    
    yline(0);
    xlabel('c');
    ylabel(boundType);
    hold off;
    
    printDirectory = (sprintf(printPath,...
        dgpChoice,tuningChoice));
    print(h,'-deps',printDirectory);

end

for iAlpha=1:nAlpha
    cBreakDownTable = table(cBreakDownCI(:,:,iAlpha));
    writetable(cBreakDownTable, tablePath, 'Sheet', iAlpha);
end
cBreakDownTable = table(cBreakDown);
writetable(cBreakDownTable, tablePath, 'Sheet', nAlpha+1);