function [ps,psDeriv,coef] = propensityScore(Data,w)
% This function calculates propensity score
%
% Inputs:
%       input1 - data
%       input2 - covariate values at which to evaluate the propensity
%       score. If not specified, the propensity score is computed for
%       Data.W.
%
% Outputs:
%       propensity score, derivative of propensity score, and propensity
%       score coefficients.
%
% Written by: Linqi Zhang
% October 2022

Data.X = categorical(Data.X);
nObs = size(Data.X,1);
nBoot = size(Data.X,3);
nCov = size(Data.W,2) + 1;

if nargin == 1
    
    ps = nan(nObs,1,nBoot);
    psDeriv = nan(nObs,nCov,nBoot);
    coef = nan(nCov,nBoot);
    
    for b = 1:size(Data.X,3)
        
        suppW = Data.W(:,:,b);
        coef(:,b) = -mnrfit(Data.W(:,:,b),Data.X(:,:,b));
        pIndex = [ones(size(Data.X,1),1),suppW] * coef(:,b);
        ps(:,:,b) = 1./(1+exp(-pIndex));
        psDeriv(:,:,b) = (1./(2+exp(-pIndex)+exp(pIndex))) .* ...
            [ones(size(Data.X,1),1), suppW];
        
    end
elseif nargin == 2
    
    ps = nan(size(w,1),1,nBoot);
    psDeriv = nan(size(w,1),nCov,nBoot);
    coef = nan(nCov,nBoot);
    
    for b = 1:size(Data.X,3)
        
        suppW = w;
        coef(:,b) = -mnrfit(Data.W(:,:,b),Data.X(:,:,b));
        pIndex = [ones(size(suppW,1),1),suppW] * coef(:,b);
        ps(:,:,b) = 1./(1+exp(-pIndex));
        psDeriv(:,:,b) = (1./(2+exp(-pIndex)+exp(pIndex))) .* ...
            [ones(size(suppW,1),1),suppW];
        
    end
end
end