function [x,y] = quantileCoefNodes(Data,tuningParams,nCov,range)
% This function calculates interpolation nodes for the quantile ceofficients
%
% range = 1: [eps-eta, 1-(eps-eta)]
% range = 2: [eps, 1-eps]
% Which range to use depends on whether we will estimate the derivative of 
% gamma(), which requires evaluating the coefficient function at eps-eta.
%
% Written by: Linqi Zhang
% October 2022

nObs = size(Data.X,1); 

x = nan(1,tuningParams.nodes);
y = nan(nCov+1,tuningParams.nodes);

if range == 1
    for i = 1:tuningParams.nodes
        x(i) = -cos((2*i - 1)*pi / (2*tuningParams.nodes));
        % The nodes were defined on [-1,1], shift them to [eps-eta, 1-(eps-eta)]
        x(i) = (tuningParams.epsilon-tuningParams.eta) + ...
            ((1-2*(tuningParams.epsilon-tuningParams.eta))/2) * (x(i)+1);
        y(:,i) = quantreg([ones(nObs,1), Data.X, Data.W], Data.Y, x(i));
    end

elseif range == 2
    for i = 1:tuningParams.nodes
        x(i) = -cos((2*i - 1)*pi / (2*tuningParams.nodes));
        % The nodes were defined on [-1,1], shift them to [eps, 1-eps]
        x(i) = tuningParams.epsilon + ...
            ((1-2*tuningParams.epsilon)/2) * (x(i)+1);
        y(:,i) = quantreg([ones(nObs,1), Data.X, Data.W], Data.Y, x(i));
    end  
end
