% Set dgp parameters
function params = setDgpParams(dgpChoice)

    if ismember(dgpChoice, [1 5 6 7 8])

        params.PI = 1; % \pi_X=1
        params.gamma = 0.1; % \gamma_X=0.1

        params.PIW = 1; % \pi_W = 1
        params.gammaW = 0.1; % \gamma_W = 0.1
        params.q = 0.5; % P(W=1)=0.5
        
        if dgpChoice==1 
            params.betaTrue = [-0.4054651081081642;0.8109302162163285]; % P(X=1|W=0)=0.4
            params.sigma = 0.9645358707834388;
        
        elseif dgpChoice==5
            params.betaTrue = [-2.1972245773362196;4.394449154672439]; % P(X=1|W=0)=0.1
            params.sigma = 0.9645358707834388;
            
        elseif dgpChoice==6
            params.betaTrue = [0;0]; % P(X=1|W=0)=0.5
            params.sigma = 0.9645358707834388; 
            
        elseif dgpChoice==7
            params.betaTrue = [-0.4054651081081642;0.8109302162163285];
            params.sigma = 1.5050222331896652;
            
        elseif dgpChoice==8
            params.betaTrue = [-0.4054651081081642;0.8109302162163285];
            params.sigma = 0.5127847578120339;
            
        end
            
        pw0index = [1,0] * params.betaTrue;
        pw1index = [1,1] * params.betaTrue;
        params.p1w0true = 1./(1+exp(-[1,0]*(params.betaTrue)));
        params.p1w1true = 1./(1+exp(-[1,1]*(params.betaTrue)));
        
        
%         params.p1w1true = ...
%             (params.p1true - params.p1w0true*(1-params.q))/params.q;
        % Be careful...this could be <= 0 or >= 1 depending on the other
        % parameters. We want this to be in (0,1)

        % The components of these two vectors should match (i.e. the first
        % vector gives the probability of the conditioning argument in the
        % corresponding component of the second vector)
        params.pW = [params.q 1-params.q]; % Should be a row vector
        params.p1hatCond = [params.p1w1true params.p1w0true]';        
        
        params.WsingleSuppSize = 2; % 2 support points for W
        
        params.p1w0derivTrue = (1./(2+exp(-pw0index)+exp(pw0index))) .* [1,0]; % used only in calculating true T2/T4
        params.p1w1derivTrue = (1./(2+exp(-pw1index)+exp(pw1index))) .* [1,1];
        clear pw0index pw1index;

        if params.p1w1true <= 0 || params.p1w1true >= 1
            error('Overlap fails');
        end        
    elseif ismember(dgpChoice, [10 11 12])
        
        params.lambda0 = -0.0208564;
        params.lambdaS = [3.804583;-1.0764500;0.2052452];
        params.lambdaC = [0.0357783;-0.020493;0.0052849];
        
        if dgpChoice == 10
            params.sigma = sqrt(0.01/12);
        elseif dgpChoice == 11
            params.sigma = sqrt(0.1/12);
        elseif dgpChoice == 12
            params.sigma = sqrt(0.5/12);
        end
    elseif ismember(dgpChoice, [13 14 15])
        
        params.lambda0 = 1;
        params.lambda1 = 1;
        params.lambda2 = 1/2;
        params.lambda3 = 1/3;
        
        if dgpChoice == 13
            params.sigma = 1;
        elseif dgpChoice == 14
            params.sigma = 2;
        elseif dgpChoice == 15
            params.sigma = 0.5;
        end
    end
   

    params.dgpChoice = dgpChoice;

end