function quantile = trueQuantileFunction_MC(params,tau,x,WsuppPoint)
% In this function, tau and x can be vectors.
% This is used, for example, in generating data for the Monte Carlo study
%
% If tau < 0 then this function returns the 0.00-quantile.
% Likewise, if tau > 1 then this function returns the 1.00-quantile.

    if ismember(params.dgpChoice, [1 5 6 7 8])
        a = -4; 
        b = 4;
    
        normalDist = makedist('normal');
        truncatedNormalDist = truncate(normalDist,a,b);
    
        dist = truncatedNormalDist;

        % Extend definition of the function to entire support in a logical way
        if tau < 0
            tau = 0;
        elseif tau > 1
            tau = 1;
        end

        if nargin == 3

            meanTerm = params.PI*x;
            stddevTerm = params.gamma*x + 1;

        elseif nargin == 4

            meanTerm = params.PI*x + params.PIW*WsuppPoint;
            stddevTerm = params.gamma*x + params.gammaW*WsuppPoint + params.sigma;

        end
    
    elseif ismember(params.dgpChoice, [10 11 12])
        % Use the dgp from Busso, DiNardo, and McCrary (2014, page 888-889)
        
        normalDist = makedist('normal');
        dist = normalDist;
        
        phiW = normcdf(WsuppPoint);
        m1 = 0.8 - 2*(phiW-0.9).^2 - 5*(phiW-0.7).^3 - 10*(phiW-0.6).^10;
        m0 = 0.4 + 0.25*sin(8*phiW-5) + 0.4*exp(-16*(phiW-2.5).^2);
        
        meanTerm = x.*m1 + (1-x).*m0;
        stddevTerm = params.sigma;
        
    elseif ismember(params.dgpChoice, [13 14 15])
        % Added on August 12, 2022
        
        normalDist = makedist('normal');
        dist = normalDist;
        
        m1 = 15 + 1*WsuppPoint + 1*WsuppPoint.^2 + (-1)*WsuppPoint.^3;
        m0 = 10 + (-1)*WsuppPoint + 0 + 0.5*WsuppPoint.^3;
        
        meanTerm = x.*m1 + (1-x).*m0;
        stddevTerm = params.sigma;
        
    end

    quantile = meanTerm + stddevTerm.*icdf(dist,tau);
end