*! v1.0.0 Matt Masten 30may2018
capture program drop leave_out_ate
program define leave_out_ate, rclass
    version 14
    syntax varlist(min=3) [if]

    local Y `1' // outcome
    local X `2' // treatment
    local YX: list Y|X // returns the union of Y and X.
    local W: list varlist-YX // a vector of observed covariates.

    // mark sample
    marksample touse
    markout `touse' `Y' `X' `W'

// BASELINE ANALYSIS
// Four different approaches to estimating ATE under selection-on-observables
// Overlap may fail for some datasets, hence we supress errors via capture
capture noisily {
    // We'll use IPW as our main baseline. Note: This choice DOES matter. Different
    // estimators give substantially different leave-out-variable K values.
    teffects ipw (`Y') (`X' `W') if `touse'

}

// Save main ATE estimate
matrix coeffs = e(b)
scalar ATEmain = coeffs[1, 1]

// Save main ATE standard error
matrix covarMat = e(V)
scalar ATEmainStdErr = sqrt(covarMat[1,1])

matrix drop coeffs covarMat

// Baseline ATT estimate
capture noisily teffects ipw (`Y') (`X' `W') if `touse', atet

// Save main ATE estimate
matrix coeffs = e(b)
scalar ATTmain = coeffs[1, 1]
scalar sampleSize = e(N)

// Save main ATE standard error
matrix covarMat = e(V)
scalar ATTmainStdErr = sqrt(covarMat[1,1])

matrix drop coeffs covarMat

// Collect baseline estimates
matrix baselineEsts = (ATEmain, ATTmain, sampleSize \ ///
                      ATEmainStdErr, ATTmainStdErr, .)
matrix colnames baselineEsts = ATE ATT "Sample size"

// LEAVE-OUT-VARIABLE K ATE ANALYSIS
// Here we compare our overall ATE estimates to ATE estimates which drop one of
// the variables.

local ncovariates : word count `W'
matrix ATEdiffs = J(`ncovariates', 1, .)
matrix rowname ATEdiffs = `W'
matrix colname ATEdiffs = ATE

local i = 1
foreach v of varlist `W' {

    // Drop variable v
    unab controlsWithoutv : `W'
    unab exclude : `v'
    local controlsWithoutv : list controlsWithoutv - exclude

    capture noisily teffects ipw (`Y') (`X' `controlsWithoutv') if `touse'
    matrix coeffs = e(b)
    
    // Save difference between main ATE estimate and ATE with variable v dropped
    matrix ATEdiffs[`i', 1] = abs(ATEmain - coeffs[1, 1])
    
    local ++i
}

matrix ATEdiffRatio = (ATEdiffs/ATEmain)*100
end
